{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-company:pyfb_company_companybalancehistory_list' %}">balance history" %}</a></p>
<table class="table">
<tr>
<td>ID</td><td>{% trans "link" %}</td>
    <td>{% trans "amount debited" %}</td>
    <td>{% trans "amount refund" %}</td>
    <td>{% trans "customer balance" %}</td>
    <td>{% trans "supplier balance" %}</td>
    <td>{% trans "operation type" %}</td>
    <td>{% trans "external description" %}</td>
    <td>{% trans "internal description" %}</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.amount_debited }}</td>
    <td>{{ object.amount_refund }}</td>
    <td>{{ object.customer_balance }}</td>
    <td>{{ object.supplier_balance }}</td>
    <td>{{ object.operation_type }}</td>
    <td>{{ object.external_desc }}</td>
    <td>{{ object.internal_desc }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-company:pyfb_company_companybalancehistory_create' %}">Create new entry" %}</a>
{% endblock %}
