# Generated by Django 2.1.4 on 2020-09-14 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_company', '0004_auto_20181210_1138'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='blocking_credit_limit',
            field=models.BooleanField(default=True, verbose_name='block calls if credit limit is reached'),
        ),
    ]
