# Generated by Django 2.1.4 on 2020-12-23 07:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_company', '0006_auto_20200917_1708'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='customer_balance_update',
            field=models.BooleanField(default=True, verbose_name='customer balance is updated after each call'),
        ),
        migrations.AddField(
            model_name='provider',
            name='provider_balance_update',
            field=models.BooleanField(default=False, verbose_name='provider balance is updated after each call'),
        ),
        migrations.AlterField(
            model_name='company',
            name='customer_balance_update',
            field=models.BooleanField(default=True, verbose_name='customer balance is updated after each call'),
        ),
    ]
