# Generated by Django 2.1.4 on 2020-12-23 07:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_company', '0007_auto_20201223_0145'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='customer_balance',
            field=models.DecimalField(decimal_places=6, default=0, help_text='actual customer balance.', max_digits=12, verbose_name='customer balance'),
        ),
        migrations.AddField(
            model_name='provider',
            name='supplier_balance',
            field=models.DecimalField(decimal_places=6, default=0, help_text='actual provider balance.', max_digits=12, verbose_name='provider balance'),
        ),
    ]
